#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_GENMASK_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_GENMASK_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/genmask.hpp>

#endif
